@@ -1,5 +1,5 @@
 package Lingua::Anagrams;
-$Lingua::Anagrams::VERSION = '0.004';
+$Lingua::Anagrams::VERSION = '0.005';
 # ABSTRACT: pure Perl anagram finder
 
 use strict;
@@ -208,10 +208,11 @@ sub _any {
 sub _anagramize {
     my $counts = shift;
     my $total  = 0;
-    $total += $_ for @$counts;
+    my @used =  @$counts[@indices];
+    $total += $_ for @used;
     my $key;
     if ( $total <= $limit ) {
-        $key = join ',', @$counts[@indices];
+        $key = join ',', @used;
         my $cached = $cache{$key};
         return @$cached if $cached;
     }
@@ -249,7 +250,7 @@ Lingua::Anagrams - pure Perl anagram finder
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
